==> vaadin-jmxconfiggenerator-17.0.1-20200124.233905-27-sources.jar: org/opennms/features/vaadin/jmxconfiggenerator/ui/mbeans/validation/MaximumLengthValidator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2015 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2015 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.jmxconfiggenerator.ui.mbeans.validation;

import com.vaadin.data.validator.StringLengthValidator;
import org.opennms.features.vaadin.jmxconfiggenerator.Config;

public class MaximumLengthValidator extends StringLengthValidator {

    protected static final String ERROR_MESSAGE = String.format("Maximal length is %d", Config.ATTRIBUTES_ALIAS_MAX_LENGTH);

    public MaximumLengthValidator() {
        super(ERROR_MESSAGE, 0, Config.ATTRIBUTES_ALIAS_MAX_LENGTH, false);
    }
}

==> vaadin-jmxconfiggenerator-21.1.0-20200409.011805-121-sources.jar: org/opennms/features/vaadin/jmxconfiggenerator/ui/mbeans/validation/MaximumLengthValidator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2015 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2015 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.jmxconfiggenerator.ui.mbeans.validation;

import org.opennms.features.vaadin.jmxconfiggenerator.Config;

import com.vaadin.data.validator.StringLengthValidator;

public class MaximumLengthValidator extends StringLengthValidator {

    protected static final String ERROR_MESSAGE = "You must specify a valid attribute name. Only characters a-z, A-Z and 0-9 are allowed.";

    public MaximumLengthValidator() {
        super(ERROR_MESSAGE, 0, Config.ATTRIBUTES_ALIAS_MAX_LENGTH, false);
    }
}
